@@ -1,21 +1,27 @@
-from sqlalchemy_declarative_extensions.dialects import postgresql
+from sqlalchemy_declarative_extensions.dialects import mysql, postgresql, sqlite
 from sqlalchemy_declarative_extensions.dialects.query import (
     check_schema_exists,
+    check_table_exists,
     get_default_grants,
     get_grants,
     get_objects,
     get_role_cls,
     get_roles,
     get_schemas,
+    get_views,
 )
 
 __all__ = [
-    "postgresql",
     "check_schema_exists",
+    "check_table_exists",
     "get_default_grants",
     "get_grants",
-    "get_roles",
     "get_objects",
     "get_role_cls",
+    "get_roles",
     "get_schemas",
+    "get_views",
+    "mysql",
+    "postgresql",
+    "sqlite",
 ]
